@@ -1,17 +1,19 @@
+# -*- coding: us-ascii -*-
 # $RoughId: extconf.rb,v 1.3 2001/08/14 19:54:51 knu Exp $
-# $Id: extconf.rb 25189 2009-10-02 12:04:37Z akr $
+# $Id: extconf.rb 52797 2015-11-30 12:08:16Z usa $
 
 require "mkmf"
 
 $defs << "-DNDEBUG" << "-DHAVE_CONFIG_H"
-$INCFLAGS << " -I$(srcdir)/.."
 
 $objs = [ "rmd160init.#{$OBJEXT}" ]
 
 dir_config("openssl")
+pkg_config("openssl")
+require File.expand_path('../../../openssl/deprecation', __FILE__)
 
 if !with_config("bundled-rmd160") &&
-    have_library("crypto") && have_header("openssl/ripemd.h")
+    have_library("crypto") && OpenSSL.check_func("RMD160_Transform", "openssl/ripemd.h")
   $objs << "rmd160ossl.#{$OBJEXT}"
 else
   $objs << "rmd160.#{$OBJEXT}"
