@@ -8,6 +8,7 @@
 #
 
 
+#--
 # == Developer Documentation (not for RDoc output)
 #
 # === Class tree
@@ -42,6 +43,8 @@
 #                         | all instances)|
 #                         +---------------+
 #
+#++
+#
 # == OptionParser
 #
 # === Introduction
@@ -108,7 +111,7 @@
 #       options.transfer_type = :auto
 #       options.verbose = false
 #
-#       opts = OptionParser.new do |opts|
+#       opt_parser = OptionParser.new do |opts|
 #         opts.banner = "Usage: example.rb [options]"
 #
 #         opts.separator ""
@@ -182,12 +185,12 @@
 #
 #         # Another typical switch to print the version.
 #         opts.on_tail("--version", "Show version") do
-#           puts OptionParser::Version.join('.')
+#           puts ::Version.join('.')
 #           exit
 #         end
 #       end
 #
-#       opts.parse!(args)
+#       opt_parser.parse!(args)
 #       options
 #     end  # parse()
 #
@@ -195,6 +198,7 @@
 #
 #   options = OptparseExample.parse(ARGV)
 #   pp options
+#   pp ARGV
 #
 # === Shell Completion
 #
@@ -204,16 +208,10 @@
 # === Further documentation
 #
 # The above examples should be enough to learn how to use this class.  If you
-# have any questions, email me (gsinclair@soyabean.com.au) and I will update
-# this document.
+# have any questions, file a ticket at http://bugs.ruby-lang.org.
 #
 class OptionParser
   # :stopdoc:
-  RCSID = %w$Id: optparse.rb 35469 2012-04-24 20:57:07Z nobu $[1..-1].each {|s| s.freeze}.freeze
-  Version = (RCSID[1].split('.').collect {|s| s.to_i}.extend(Comparable).freeze if RCSID[1])
-  LastModified = (Time.gm(*RCSID[2, 2].join('-').scan(/\d+/).collect {|s| s.to_i}) if RCSID[2])
-  Release = RCSID[2]
-
   NoArgument = [NO_ARGUMENT = :NONE, nil].freeze
   RequiredArgument = [REQUIRED_ARGUMENT = :REQUIRED, true].freeze
   OptionalArgument = [OPTIONAL_ARGUMENT = :OPTIONAL, false].freeze
@@ -449,7 +447,7 @@ class OptionParser
 
       (sopts+lopts).each do |opt|
         # "(-x -c -r)-l[left justify]" \
-        if opt =~ /^--\[no-\](.+)$/
+        if /^--\[no-\](.+)$/ =~ opt
           o = $1
           yield("--#{o}", desc.join(""))
           yield("--no-#{o}", desc.join(""))
@@ -734,7 +732,7 @@ class OptionParser
   # OPTIONAL_ARGUMENT:: The switch requires an optional argument. (:OPTIONAL)
   #
   # Use like --switch=argument (long style) or -Xargument (short style). For
-  # short style, only portion matched to argument pattern is dealed as
+  # short style, only portion matched to argument pattern is treated as
   # argument.
   #
   ArgumentStyle = {}
@@ -1090,7 +1088,7 @@ XXX
   end
   private :notwice
 
-  SPLAT_PROC = proc {|*a| a.length <= 1 ? a.first : a}
+  SPLAT_PROC = proc {|*a| a.length <= 1 ? a.first : a} # :nodoc:
   #
   # Creates an OptionParser::Switch from the parameters. The parsed argument
   # value is passed to the given block, where it can be processed.
@@ -1336,6 +1334,7 @@ XXX
 
   #
   # Same as #order, but removes switches destructively.
+  # Non-option arguments remain in +argv+.
   #
   def order!(argv = default_argv, &nonopt)
     parse_in_order(argv, &nonopt)
@@ -1426,6 +1425,7 @@ XXX
 
   #
   # Same as #permute, but removes switches destructively.
+  # Non-option arguments remain in +argv+.
   #
   def permute!(argv = default_argv)
     nonopts = []
@@ -1445,6 +1445,7 @@ XXX
 
   #
   # Same as #parse, but removes switches destructively.
+  # Non-option arguments remain in +argv+.
   #
   def parse!(argv = default_argv)
     if ENV.include?('POSIXLY_CORRECT')
@@ -1631,15 +1632,22 @@ XXX
   decimal = '\d+(?:_\d+)*'
   binary = 'b[01]+(?:_[01]+)*'
   hex = 'x[\da-f]+(?:_[\da-f]+)*'
-  octal = "0(?:[0-7]*(?:_[0-7]+)*|#{binary}|#{hex})"
+  octal = "0(?:[0-7]+(?:_[0-7]+)*|#{binary}|#{hex})?"
   integer = "#{octal}|#{decimal}"
-  accept(Integer, %r"\A[-+]?(?:#{integer})"io) {|s,| Integer(s) if s}
+
+  accept(Integer, %r"\A[-+]?(?:#{integer})\z"io) {|s,|
+    begin
+      Integer(s)
+    rescue ArgumentError
+      raise OptionParser::InvalidArgument, s
+    end if s
+  }
 
   #
   # Float number format, and converts to Float.
   #
   float = "(?:#{decimal}(?:\\.(?:#{decimal})?)?|\\.#{decimal})(?:E[-+]?#{decimal})?"
-  floatpat = %r"\A[-+]?#{float}"io
+  floatpat = %r"\A[-+]?#{float}\z"io
   accept(Float, floatpat) {|s,| s.to_f if s}
 
   #
@@ -1647,7 +1655,7 @@ XXX
   # for float format, and Rational for rational format.
   #
   real = "[-+]?(?:#{octal}|#{float})"
-  accept(Numeric, /\A(#{real})(?:\/(#{real}))?/io) {|s, d, n|
+  accept(Numeric, /\A(#{real})(?:\/(#{real}))?\z/io) {|s, d, n|
     if n
       Rational(d, n)
     elsif s
@@ -1658,22 +1666,40 @@ XXX
   #
   # Decimal integer format, to be converted to Integer.
   #
-  DecimalInteger = /\A[-+]?#{decimal}/io
-  accept(DecimalInteger) {|s,| s.to_i if s}
+  DecimalInteger = /\A[-+]?#{decimal}\z/io
+  accept(DecimalInteger, DecimalInteger) {|s,|
+    begin
+      Integer(s)
+    rescue ArgumentError
+      raise OptionParser::InvalidArgument, s
+    end if s
+  }
 
   #
   # Ruby/C like octal/hexadecimal/binary integer format, to be converted to
   # Integer.
   #
-  OctalInteger = /\A[-+]?(?:[0-7]+(?:_[0-7]+)*|0(?:#{binary}|#{hex}))/io
-  accept(OctalInteger) {|s,| s.oct if s}
+  OctalInteger = /\A[-+]?(?:[0-7]+(?:_[0-7]+)*|0(?:#{binary}|#{hex}))\z/io
+  accept(OctalInteger, OctalInteger) {|s,|
+    begin
+      Integer(s, 8)
+    rescue ArgumentError
+      raise OptionParser::InvalidArgument, s
+    end if s
+  }
 
   #
   # Decimal integer/float number format, to be converted to Integer for
   # integer format, Float for float format.
   #
   DecimalNumeric = floatpat     # decimal integer is allowed as float also.
-  accept(DecimalNumeric) {|s,| eval(s) if s}
+  accept(DecimalNumeric, floatpat) {|s,|
+    begin
+      eval(s)
+    rescue SyntaxError
+      raise OptionParser::InvalidArgument, s
+    end if s
+  }
 
   #
   # Boolean switch, which means whether it is present or not, whether it is
@@ -1928,10 +1954,3 @@ end
 
 # ARGV is arguable by OptionParser
 ARGV.extend(OptionParser::Arguable)
-
-if $0 == __FILE__
-  Version = OptionParser::Version
-  ARGV.options {|q|
-    q.parse!.empty? or print "what's #{ARGV.join(' ')}?\n"
-  } or abort(ARGV.options.to_s)
-end
