@@ -70,6 +70,22 @@ class TestSocket < Test::Unit::TestCase
     }
   end
 
+  def test_bind
+    Socket.open(Socket::AF_INET, Socket::SOCK_STREAM, 0) {|bound|
+      bound.bind(Socket.sockaddr_in(0, "127.0.0.1"))
+      addr = bound.getsockname
+      port, = Socket.unpack_sockaddr_in(addr)
+
+      Socket.open(Socket::AF_INET, Socket::SOCK_STREAM, 0) {|s|
+        e = assert_raises(Errno::EADDRINUSE) do
+          s.bind(Socket.sockaddr_in(port, "127.0.0.1"))
+        end
+
+        assert_match "bind(2) for 127.0.0.1:#{port}", e.message
+      }
+    }
+  end
+
   def test_getaddrinfo
     # This should not send a DNS query because AF_UNIX.
     assert_raise(SocketError) { Socket.getaddrinfo("www.kame.net", 80, "AF_UNIX") }
@@ -343,7 +359,6 @@ class TestSocket < Test::Unit::TestCase
             # Mac OS X may sets IFDISABLED as FreeBSD does
             ulSIOCGIFFLAGS = 3223349521
             ulSIOCGIFINFO_IN6 = 3224398156
-            ulSIOCGIFAFLAG_IN6 = 3240126793
             ulIFF_POINTOPOINT = 0x10
             ulND6_IFF_IFDISABLED = 8
             in6_ondireq = ifr_name
@@ -387,14 +402,14 @@ class TestSocket < Test::Unit::TestCase
               raise "no response from #{ai.inspect} #{nd6options}ping=#{ping_p}"
             end
             msg2, addr = s.recvmsg
-            msg2, remote_address, local_address = Marshal.load(msg2)
+            msg2, _, _ = Marshal.load(msg2)
             assert_equal(msg1, msg2)
             assert_equal(ai.ip_address, addr.ip_address)
           }
         }
       rescue NotImplementedError, Errno::ENOSYS
         skipped = true
-        skip "need sendmsg and recvmsg"
+        skip "need sendmsg and recvmsg: #{$!}"
       ensure
         if th
           if skipped
@@ -438,7 +453,7 @@ class TestSocket < Test::Unit::TestCase
       Addrinfo.udp("127.0.0.1", 0).bind {|s2|
         s1.setsockopt(:SOCKET, :TIMESTAMP, true)
         s2.send "a", 0, s1.local_address
-        msg, addr, rflags, stamp = s1.recvmsg
+        msg, _, _, stamp = s1.recvmsg
         assert_equal("a", msg)
         assert(stamp.cmsg_is?(:SOCKET, :TIMESTAMP))
       }
@@ -465,7 +480,7 @@ class TestSocket < Test::Unit::TestCase
           return
         end
         s2.send "a", 0, s1.local_address
-        msg, addr, rflags, stamp = s1.recvmsg
+        msg, _, _, stamp = s1.recvmsg
         assert_equal("a", msg)
         assert(stamp.cmsg_is?(:SOCKET, :TIMESTAMPNS))
       }
@@ -487,7 +502,7 @@ class TestSocket < Test::Unit::TestCase
       Addrinfo.udp("127.0.0.1", 0).bind {|s2|
         s1.setsockopt(:SOCKET, :BINTIME, true)
         s2.send "a", 0, s1.local_address
-        msg, addr, rflags, stamp = s1.recvmsg
+        msg, _, _, stamp = s1.recvmsg
         assert_equal("a", msg)
         assert(stamp.cmsg_is?(:SOCKET, :BINTIME))
       }
@@ -549,6 +564,17 @@ class TestSocket < Test::Unit::TestCase
     sock.close if sock && ! sock.closed?
   end
 
+  def test_getifaddrs
+    begin
+      list = Socket.getifaddrs
+    rescue NotImplementedError
+      return
+    end
+    list.each {|ifaddr|
+      assert_instance_of(Socket::Ifaddr, ifaddr)
+    }
+  end
+
   def test_connect_in_rescue
     serv = Addrinfo.tcp(nil, 0).listen
     addr = serv.connect_address
